================================
Panoramisk. The Asterisk's druid
================================

.. image:: https://travis-ci.org/gawel/panoramisk.png?branch=master&style=flat-square
        :target: https://travis-ci.org/gawel/panoramisk

.. image:: https://img.shields.io/coveralls/gawel/panoramisk/master.svg
        :target: https://coveralls.io/r/gawel/panoramisk?branch=master

.. image:: https://img.shields.io/pypi/v/panoramisk.svg?style=flat-square
        :target: https://pypi.python.org/pypi/panoramisk

.. image:: https://img.shields.io/pypi/dw/panoramisk.svg?style=flat-square
        :target: https://pypi.python.org/pypi/panoramisk

.. image:: https://img.shields.io/github/issues/gawel/panoramisk.svg?style=flat-square
        :target: https://github.com/gawel/panoramisk/issues

.. image:: https://img.shields.io/github/license/gawel/panoramisk.svg?style=flat-square
        :target: https://github.com/gawel/panoramisk/blob/master/LICENSE


`Panoramisk` is a library based on python's `AsyncIO
<http://docs.python.org/dev/library/asyncio.html>`_ to play with `Asterisk
<http://www.asterisk.org/community/documentation>`_'s `manager
<https://wiki.asterisk.org/wiki/display/AST/The+Asterisk+Manager+TCP+IP+API>`_.

It uses the TCP manager server to listen to events and send actions.

For basic usage, you have some examples in `examples/
<https://github.com/gawel/panoramisk/tree/master/examples>`_ folder.

You can find some help on IRC: irc://irc.freenode.net/panoramisk (`www
<https://kiwiirc.com/client/irc.freenode.net/?nick=panoramisk|?&theme=basic#panoramisk>`_)


Source code is available at https://github.com/gawel/panoramisk/


Check the `full documentation <https://panoramisk.readthedocs.org/>`_


I've spent hours writing this software, with love.
Please consider tiping if you like it:

BTC: 1PruQAwByDndFZ7vTeJhyWefAghaZx9RZg

ETH: 0xb6418036d8E06c60C4D91c17d72Df6e1e5b15CE6

LTC: LY6CdZcDbxnBX9GFBJ45TqVj8NykBBqsmT
